@@ -20,6 +20,7 @@ eval {
   require MMS::Mail::Provider::UKOrange;
   require MMS::Mail::Provider::UKTMobile;
   require MMS::Mail::Provider::UKVirgin;
+  require MMS::Mail::Provider::UK3;
 };
 
 =head1 NAME
@@ -28,11 +29,11 @@ MMS::Mail::Parser - A class for parsing MMS (or picture) messages via email.
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
@@ -521,6 +522,12 @@ sub _decipher {
     if (defined($@) && $@) { return undef; }
     $self->provider($provider);
     return $provider->parse($self->message);
+  } elsif ($self->message->header_from =~ /mms.three.co.uk/) {
+    print STDERR "3 message type detected\n" if ($self->debug);
+    my $provider = eval { new MMS::Mail::Provider::UK3 };
+    if (defined($@) && $@) { return undef; }
+    $self->provider($provider);
+    return $provider->parse($self->message);
   } else {
     print STDERR "No message type detected using base provider\n" if ($self->debug);
     my $provider = new MMS::Mail::Provider;
